@@ -110,6 +110,39 @@ test_that("select population two_alleles multiple markers", {
   testthat::expect_true(verify_population(selected_pop$population))
 })
 
+test_that("select population two_alleles multiply vs sum", {
+  testthat::skip_on_os("solaris")
+  select_matrix <- matrix(ncol = 5, nrow = 2)
+  s <- 0.2
+  select_matrix[1, ] <- c(0.25, 1.0, 1 + 0.5 * s, 1 + s, 0)
+  select_matrix[2, ] <- c(0.75, 1.0, 1, 1 + s,  1)
+
+  selected_pop <- simulate_admixture(module =
+                                       ancestry_module(number_of_founders = 10,
+                                                       markers = c(0.25, 0.75)),
+                                     pop_size = 100,
+                                     total_runtime = 100,
+                                     select_matrix = select_matrix,
+                                     multiplicative_selection = TRUE)
+
+  selected_pop2 <- simulate_admixture(module =
+                                       ancestry_module(number_of_founders = 10,
+                                                       markers = c(0.25, 0.75)),
+                                     pop_size = 100,
+                                     total_runtime = 100,
+                                     select_matrix = select_matrix,
+                                     multiplicative_selection = FALSE)
+
+  vv <- GenomeAdmixR::calculate_marker_frequency(selected_pop,
+                                                 location = c(0.25, 0.75))
+  vv2 <- GenomeAdmixR::calculate_marker_frequency(selected_pop2,
+                                                  location = c(0.25, 0.75))
+
+  testthat::expect_gt(length(vv2$ancestor), 1)
+
+  testthat::expect_gt(length(vv$ancestor), 1)
+})
+
 test_that("select population two_alleles regions", {
   testthat::skip_on_os("solaris")
   select_matrix <- matrix(ncol = 5, nrow = 2)
